@@ -353,7 +353,7 @@ log_write (session *sess, char *text)
 				g_free (stamp);
 			}
 		}
-		temp = strip_color (text, -1, 1, 1);
+		temp = strip_color (text, -1, STRIP_ALL);
 		len = strlen (temp);
 		write (sess->logfd, temp, len);
 		/* lots of scripts/plugins print without a \n at the end */
@@ -1115,14 +1115,11 @@ pevent_load (char *filename)
 	int penum = 0;
 	char *ofs;
 
-	buf = malloc (1000);
 	if (filename == NULL)
-		snprintf (buf, 1000, "%s/pevents.conf", get_xdir_fs ());
-   else
-      safe_strcpy (buf, filename, 1000);
+		fd = xchat_open_file ("pevents.conf", O_RDONLY, 0, 0);
+	else
+		fd = xchat_open_file (filename, O_RDONLY, 0, XOF_FULLPATH);
 
-	fd = open (buf, O_RDONLY | OFLAGS);
-	free (buf);
 	if (fd == -1)
 		return 1;
 	if (fstat (fd, &st) != 0)
@@ -1235,8 +1232,15 @@ load_text_events ()
 	pevent_make_pntevts ();
 }
 
+/*
+	CL: format_event now handles filtering of arguments:
+	1) if prefs.stripcolor is set, filter all style control codes from arguments
+	2) always strip \001 (ATTR_HIDDEN) from arguments: it is only for use in the format string itself
+*/
+#define ARG_FLAG(argn) (1 << argn)
+
 void
-format_event (session *sess, int index, char **args, char *o, int sizeofo)
+format_event (session *sess, int index, char **args, char *o, int sizeofo, unsigned int stripcolor_args)
 {
 	int len, oi, ii, numargs;
 	char *i, *ar, d, a, done_all = FALSE;
@@ -1283,8 +1287,8 @@ format_event (session *sess, int index, char **args, char *o, int sizeofo)
 				printf ("arg[%d] is NULL in print event\n", a + 1);
 			} else
 			{
-				len = strlen (ar);
-				memcpy (&o[oi], ar, len);
+				if (stripcolor_args & ARG_FLAG(a + 1)) len = strip_color2 (ar, -1, &o[oi], STRIP_ALL);
+				else len = strip_hidden_attribute (ar, &o[oi]);
 				oi += len;
 			}
 			break;
@@ -1316,10 +1320,10 @@ format_event (session *sess, int index, char **args, char *o, int sizeofo)
 }
 
 static void
-display_event (session *sess, int event, char **args)
+display_event (session *sess, int event, char **args, unsigned int stripcolor_args)
 {
 	char o[4096];
-	format_event (sess, event, args, o, sizeof (o));
+	format_event (sess, event, args, o, sizeof (o), stripcolor_args);
 	if (o[0])
 		PrintText (sess, o);
 }
@@ -1500,6 +1504,25 @@ pevt_build_string (const char *input, char **output, int *max_arg)
 	return 0;
 }
 
+
+/* black n white(0/1) are bad colors for nicks, and we'll use color 2 for us */
+/* also light/dark gray (14/15) */
+/* 5,7,8 are all shades of yellow which happen to look dman near the same */
+
+static char rcolors[] = { 19, 20, 22, 24, 25, 26, 27, 28, 29 };
+
+static int
+color_of (char *name)
+{
+	int i = 0, sum = 0;
+
+	while (name[i])
+		sum += name[i++];
+	sum %= sizeof (rcolors) / sizeof (char);
+	return rcolors[sum];
+}
+
+
 /* called by EMIT_SIGNAL macro */
 
 void
@@ -1507,21 +1530,21 @@ text_emit (int index, session *sess, char *a, char *b, char *c, char *d)
 {
 	char *word[PDIWORDS];
 	int i;
+	unsigned int stripcolor_args = (prefs.stripcolor ? 0xFFFFFFFF : 0);
+	char tbuf[NICKLEN + 4];
 
-	if (!a)
-		a = "\000";
-	if (!b)
-		b = "\000";
-	if (!c)
-		c = "\000";
-	if (!d)
-		d = "\000";
+	if (prefs.colorednicks && (index == XP_TE_CHANACTION || index == XP_TE_CHANMSG))
+	{
+		snprintf (tbuf, sizeof (tbuf), "\003%d%s", color_of (a), a);
+		a = tbuf;
+		stripcolor_args &= ~ARG_FLAG(1);	/* don't strip color from this argument */
+	}
 
 	word[0] = te[index].name;
-	word[1] = a;
-	word[2] = b;
-	word[3] = c;
-	word[4] = d;
+	word[1] = (a ? a : "\000");
+	word[2] = (b ? b : "\000");
+	word[3] = (c ? c : "\000");
+	word[4] = (d ? d : "\000");
 	for (i = 5; i < PDIWORDS; i++)
 		word[i] = "\000";
 
@@ -1532,7 +1555,7 @@ text_emit (int index, session *sess, char *a, char *b, char *c, char *d)
 
 	/* If a plugin's callback executes "/close", 'sess' may be invalid */
 	if (is_session (sess))
-		display_event (sess, index, word);
+		display_event (sess, index, word, stripcolor_args);
 }
 
 int
@@ -1557,10 +1580,11 @@ pevent_save (char *fn)
 	char buf[1024];
 
 	if (!fn)
-		snprintf (buf, sizeof (buf), "%s/pevents.conf", get_xdir_fs ());
+		fd = xchat_open_file ("pevents.conf", O_CREAT | O_TRUNC | O_WRONLY,
+									 0x180, XOF_DOMODE);
 	else
-		safe_strcpy (buf, fn, sizeof (buf));
-	fd = open (buf, O_CREAT | O_TRUNC | O_WRONLY | OFLAGS, 0x180);
+		fd = xchat_open_file (fn, O_CREAT | O_TRUNC | O_WRONLY, 0x180,
+									 XOF_FULLPATH | XOF_DOMODE);
 	if (fd == -1)
 	{
 		/*
@@ -1721,8 +1745,7 @@ sound_load ()
 
 	memset (&sound_files, 0, sizeof (char *) * (NUM_XP));
 
-	snprintf (buf, sizeof (buf), "%s/sound.conf", get_xdir_fs ());
-	fd = open (buf, O_RDONLY | OFLAGS);
+	fd = xchat_open_file ("sound.conf", O_RDONLY, 0, 0);
 	if (fd == -1)
 		return;
 
@@ -1752,8 +1775,8 @@ sound_save ()
 	int fd, i;
 	char buf[512];
 
-	snprintf (buf, sizeof (buf), "%s/sound.conf", get_xdir_fs ());
-	fd = open (buf, O_CREAT | O_TRUNC | O_WRONLY | OFLAGS, 0x180);
+	fd = xchat_open_file ("sound.conf", O_CREAT | O_TRUNC | O_WRONLY, 0x180,
+								 XOF_DOMODE);
 	if (fd == -1)
 		return;
 
