@@ -4,12 +4,6 @@
 #define XCHAT_TEXT_H
 
 #define EMIT_SIGNAL(i, sess, a, b, c, d, e) text_emit(i, sess, a, b, c, d)
-#define WORD_URL     1
-#define WORD_NICK    2
-#define WORD_CHANNEL 3
-#define WORD_HOST    4
-#define WORD_EMAIL   5
-#define WORD_DIALOG  -1
 
 struct text_event
 {
@@ -19,7 +13,7 @@ struct text_event
 	char *def;
 };
 
-int text_word_check (char *word);
+int text_word_check (char *word, int len);
 void PrintText (session *sess, char *text);
 void PrintTextf (session *sess, char *format, ...);
 void log_close (session *sess);
@@ -33,6 +27,7 @@ void text_emit (int index, session *sess, char *a, char *b, char *c, char *d);
 int text_emit_by_name (char *name, session *sess, char *a, char *b, char *c, char *d);
 char *text_validate (char **text, int *len);
 int get_stamp_str (char *fmt, time_t tim, char **ret);
+void format_event (session *sess, int index, char **args, char *o, int sizeofo, unsigned int stripcolor_args);
 
 void sound_play (const char *file);
 void sound_play_event (int i);
