@@ -60,19 +60,18 @@ GSList *command_list = 0;
 GSList *ctcp_list = 0;
 GSList *replace_list = 0;
 GSList *sess_list = 0;
-GSList *serv_list = 0;
 GSList *dcc_list = 0;
 GSList *ignore_list = 0;
 GSList *usermenu_list = 0;
 GSList *urlhandler_list = 0;
 GSList *tabmenu_list = 0;
-static GSList *away_list = 0;
 
 static int in_xchat_exit = FALSE;
 int xchat_is_quitting = FALSE;
-int auto_connect = TRUE;
-int skip_plugins = FALSE;
-char *connect_url = NULL;
+/* command-line args */
+int arg_dont_autoconnect = FALSE;
+int arg_skip_plugins = FALSE;
+char *arg_url = NULL;
 
 struct session *current_tab;
 struct session *current_sess = 0;
@@ -83,12 +82,6 @@ SSL_CTX *ctx = NULL;
 #endif
 
 
-int
-is_server (server * serv)
-{
-	return g_slist_find (serv_list, serv) ? 1 : 0;
-}
-
 int
 is_session (session * sess)
 {
@@ -283,7 +276,7 @@ irc_init (session *sess)
 	done_init = TRUE;
 
 #ifdef USE_PLUGIN
-	if (!skip_plugins)
+	if (!arg_skip_plugins)
 		plugin_auto_load (sess);	/* autoload ~/.xchat *.so */
 #endif
 	plugin_add (sess, NULL, NULL, timer_plugin_init, NULL, NULL, FALSE);
@@ -295,17 +288,17 @@ irc_init (session *sess)
 	fe_timeout_add (prefs.away_timeout * 1000, away_check, 0);
 	fe_timeout_add (500, xchat_misc_checks, 0);
 
-	if (connect_url != NULL)
+	if (arg_url != NULL)
 	{
 		char buf[512];
-		snprintf (buf, sizeof (buf), "server %s", connect_url);
+		snprintf (buf, sizeof (buf), "server %s", arg_url);
 		handle_command (sess, buf, FALSE);
-		free (connect_url);
+		g_free (arg_url);	/* from GOption */
 	}
 }
 
 static session *
-new_session (server *serv, char *from, int type, int focus)
+session_new (server *serv, char *from, int type, int focus)
 {
 	session *sess;
 
@@ -340,17 +333,17 @@ new_ircwindow (server *serv, char *name, int type, int focus)
 		{
 			register unsigned int oldh = prefs.hideuserlist;
 			prefs.hideuserlist = 1;
-			sess = new_session (serv, name, SESS_SERVER, focus);
+			sess = session_new (serv, name, SESS_SERVER, focus);
 			prefs.hideuserlist = oldh;
 		} else
 		{
-			sess = new_session (serv, name, SESS_CHANNEL, focus);
+			sess = session_new (serv, name, SESS_CHANNEL, focus);
 		}
 		serv->server_session = sess;
 		serv->front_session = sess;
 		break;
 	case SESS_DIALOG:
-		sess = new_session (serv, name, type, focus);
+		sess = session_new (serv, name, type, focus);
 		if (prefs.logging)
 			log_open (sess);
 		break;
@@ -358,7 +351,7 @@ new_ircwindow (server *serv, char *name, int type, int focus)
 /*	case SESS_CHANNEL:
 	case SESS_NOTICES:
 	case SESS_SNOTICES:*/
-		sess = new_session (serv, name, type, focus);
+		sess = session_new (serv, name, type, focus);
 		break;
 	}
 
@@ -368,82 +361,6 @@ new_ircwindow (server *serv, char *name, int type, int focus)
 	return sess;
 }
 
-static void
-free_away_messages (server *serv)
-{
-	GSList *list, *next;
-	struct away_msg *away;
-
-	list = away_list;
-	while (list)
-	{
-		away = list->data;
-		next = list->next;
-		if (away->server == serv)
-		{
-			away_list = g_slist_remove (away_list, away);
-			if (away->message)
-				free (away->message);
-			free (away);
-			next = away_list;
-		}
-		list = next;
-	}
-}
-
-void
-save_away_message (struct server *serv, char *nick, char *msg)
-{
-	struct away_msg *away = find_away_message (serv, nick);
-
-	if (away)						  /* Change message for known user */
-	{
-		if (away->message)
-			free (away->message);
-		away->message = strdup (msg);
-	} else
-		/* Create brand new entry */
-	{
-		away = malloc (sizeof (struct away_msg));
-		if (away)
-		{
-			away->server = serv;
-			safe_strcpy (away->nick, nick, sizeof (away->nick));
-			away->message = strdup (msg);
-			away_list = g_slist_prepend (away_list, away);
-		}
-	}
-}
-
-static void
-kill_server_callback (server * serv)
-{
-	serv->cleanup (serv);
-
-	serv_list = g_slist_remove (serv_list, serv);
-
-	dcc_notify_kill (serv);
-	serv->flush_queue (serv);
-	free_away_messages (serv);
-
-	free (serv->nick_modes);
-	free (serv->nick_prefixes);
-	free (serv->chanmodes);
-	free (serv->chantypes);
-	if (serv->bad_nick_prefixes)
-		free (serv->bad_nick_prefixes);
-	if (serv->last_away_reason)
-		free (serv->last_away_reason);
-	if (serv->encoding)
-		free (serv->encoding);
-
-	fe_server_callback (serv);
-
-	free (serv);
-
-	notify_cleanup ();
-}
-
 static void
 exec_notify_kill (session * sess)
 {
@@ -509,7 +426,7 @@ send_quit_or_part (session * killsess)
 }
 
 void
-kill_session_callback (session * killsess)
+session_free (session *killsess)
 {
 	server *killserv = killsess->server;
 	session *sess;
@@ -548,7 +465,7 @@ kill_session_callback (session * killsess)
 	sess_list = g_slist_remove (sess_list, killsess);
 
 	if (killsess->type == SESS_CHANNEL)
-		free_userlist (killsess);
+		userlist_free (killsess);
 
 	exec_notify_kill (killsess);
 
@@ -581,7 +498,7 @@ kill_session_callback (session * killsess)
 		list = list->next;
 	}
 
-	kill_server_callback (killserv);
+	server_free (killserv);
 }
 
 static void
@@ -596,20 +513,7 @@ free_sessions (void)
 	}
 }
 
-struct away_msg *
-find_away_message (struct server *serv, char *nick)
-{
-	struct away_msg *away;
-	GSList *list = away_list;
-	while (list)
-	{
-		away = (struct away_msg *) list->data;
-		if (away->server == serv && !serv->p_cmp (nick, away->nick))
-			return away;
-		list = list->next;
-	}
-	return 0;
-}
+
 
 #define XTERM "gnome-terminal -x "
 
@@ -651,9 +555,13 @@ static char defaultconf_commands[] =
 	"NAME WALLOPS\n"		"CMD quote WALLOPS :&2\n\n"\
 	"NAME WII\n"			"CMD quote WHOIS %2 %2\n\n";
 
+#if 1
+static char defaultconf_urlhandlers[] =
+		"NAME Open Link in Opera\n"		"CMD !opera -remote 'openURL(%s)'\n\n";
+#else
 #ifdef WIN32
 static char defaultconf_urlhandlers[] =
-	"NAME Connect as IRC server\n"		"CMD newserver %s\n\n";
+	"NAME Connect as IRC server\n"		"CMD url %s\n\n";
 #else
 static char defaultconf_urlhandlers[] =
 	"NAME SUB\n"								"CMD Epiphany...\n\n"\
@@ -691,7 +599,7 @@ static char defaultconf_urlhandlers[] =
 		"NAME Run new Opera\n"				"CMD !opera %s\n\n"\
 	"NAME ENDSUB\n"							"CMD \n\n"\
 	"NAME SUB\n"								"CMD Send URL to...\n\n"\
-		"NAME Gnome URL Handler\n"			"CMD !gnome-moz-remote %s\n\n"\
+		"NAME Gnome URL Handler\n"			"CMD !gnome-open %s\n\n"\
 		"NAME Lynx\n"							"CMD !"XTERM"lynx %s\n\n"\
 		"NAME Links\n"							"CMD !"XTERM"links %s\n\n"\
 		"NAME w3m\n"							"CMD !"XTERM"w3m %s\n\n"\
@@ -701,7 +609,8 @@ static char defaultconf_urlhandlers[] =
 		"NAME Telnet\n"						"CMD !"XTERM"telnet %s\n\n"\
 		"NAME Ping\n"							"CMD !"XTERM"ping -c 4 %s\n\n"\
 	"NAME ENDSUB\n"							"CMD \n\n"\
-	"NAME Connect as IRC server\n"		"CMD newserver %s\n\n";
+	"NAME Connect as IRC server\n"		"CMD url %s\n\n";
+#endif
 #endif
 
 #ifdef USE_SIGACTION
@@ -797,6 +706,57 @@ xchat_init (void)
 	notify_load ();
 	ignore_load ();
 
+	snprintf (buf, sizeof (buf),
+		"NAME %s\n"						"CMD query %%s\n\n"\
+		"NAME %s\n"						"CMD send %%s\n\n"\
+		"NAME %s\n"						"CMD whois %%s %%s\n\n"\
+
+		"NAME SUB\n"					"CMD %s\n\n"\
+			"NAME %s\n"					"CMD op %%a\n\n"\
+			"NAME %s\n"					"CMD deop %%a\n\n"\
+			"NAME SEP\n"				"CMD \n\n"\
+			"NAME %s\n"					"CMD voice %%a\n\n"\
+			"NAME %s\n"					"CMD devoice %%a\n"\
+			"NAME SEP\n"				"CMD \n\n"\
+			"NAME SUB\n"				"CMD %s\n\n"\
+				"NAME %s\n"				"CMD kick %%s\n\n"\
+				"NAME %s\n"				"CMD ban %%s\n\n"\
+				"NAME SEP\n"			"CMD \n\n"\
+				"NAME %s *!*@*.host\n""CMD ban %%s 0\n\n"\
+				"NAME %s *!*@domain\n""CMD ban %%s 1\n\n"\
+				"NAME %s *!*user@*.host\n""CMD ban %%s 2\n\n"\
+				"NAME %s *!*user@domain\n""CMD ban %%s 3\n\n"\
+				"NAME SEP\n"			"CMD \n\n"\
+				"NAME %s *!*@*.host\n""CMD kickban %%s 0\n\n"\
+				"NAME %s *!*@domain\n""CMD kickban %%s 1\n\n"\
+				"NAME %s *!*user@*.host\n""CMD kickban %%s 2\n\n"\
+				"NAME %s *!*user@domain\n""CMD kickban %%s 3\n\n"\
+			"NAME ENDSUB\n"			"CMD \n\n"\
+		"NAME ENDSUB\n"				"CMD \n\n",
+
+		_("Open Dialog Window"),
+		_("Send a File"),
+		_("User Info (WHOIS)"),
+		_("Operator Actions"),
+
+		_("Give Ops"),
+		_("Take Ops"),
+		_("Give Voice"),
+		_("Take Voice"),
+
+		_("Kick/Ban"),
+		_("Kick"),
+		_("Ban"),
+		_("Ban"),
+		_("Ban"),
+		_("Ban"),
+		_("Ban"),
+		_("KickBan"),
+		_("KickBan"),
+		_("KickBan"),
+		_("KickBan"));
+
+#if 0
 	snprintf (buf, sizeof (buf),
 	"NAME SUB\n"				"CMD %s\n\n"\
 		"NAME %s\n"				"CMD dcc send %%s\n\n"\
@@ -902,18 +862,15 @@ xchat_init (void)
 		_("Telnet"),
 		_("Open Dialog Window")
 		);
+#endif
 	list_loadconf ("popup.conf", &popup_list, buf);
 
 	snprintf (buf, sizeof (buf),
-		"NAME %s\n"				"CMD discon\n\n"
-		"NAME %s\n"				"CMD reconnect\n\n"
 		"NAME %s\n"				"CMD part\n\n"
 		"NAME %s\n"				"CMD getstr # join \"%s\"\n\n"
 		"NAME %s\n"				"CMD quote LINKS\n\n"
 		"NAME %s\n"				"CMD ping\n\n"
 		"NAME TOGGLE %s\n"	"CMD irc_hide_version\n\n",
-				_("Disconnect"),
-				_("Reconnect"),
 				_("Leave Channel"),
 				_("Join Channel..."),
 				_("Enter Channel to Join:"),
@@ -927,7 +884,7 @@ xchat_init (void)
 		"NAME %s\n"		"CMD deop %%a\n\n"
 		"NAME %s\n"		"CMD ban %%s\n\n"
 		"NAME %s\n"		"CMD getstr %s \"kick %%s\" \"%s\"\n\n"
-		"NAME %s\n"		"CMD dcc send %%s\n\n"
+		"NAME %s\n"		"CMD send %%s\n\n"
 		"NAME %s\n"		"CMD query %%s\n\n",
 				_("Op"),
 				_("DeOp"),
@@ -941,7 +898,7 @@ xchat_init (void)
 
 	snprintf (buf, sizeof (buf),
 		"NAME %s\n"				"CMD whois %%s %%s\n\n"
-		"NAME %s\n"				"CMD dcc send %%s\n\n"
+		"NAME %s\n"				"CMD send %%s\n\n"
 		"NAME %s\n"				"CMD dcc chat %%s\n\n"
 		"NAME %s\n"				"CMD clear\n\n"
 		"NAME %s\n"				"CMD ping %%s\n\n",
@@ -961,17 +918,18 @@ xchat_init (void)
 
 	servlist_init ();							/* load server list */
 
-	if (!prefs.slist_skip)
+	/* if we got a URL, don't open the server list GUI */
+	if (!prefs.slist_skip && !arg_url)
 		fe_serverlist_open (NULL);
 
 	/* turned OFF via -a arg */
-	if (auto_connect)
+	if (!arg_dont_autoconnect)
 	{
 		/* do any auto connects */
 		if (!servlist_have_auto ())	/* if no new windows open .. */
 		{
 			/* and no serverlist gui ... */
-			if (prefs.slist_skip || connect_url)
+			if (prefs.slist_skip || arg_url)
 				/* we'll have to open one. */
 				new_ircwindow (NULL, NULL, SESS_SERVER, 0);
 		} else
@@ -980,7 +938,7 @@ xchat_init (void)
 		}
 	} else
 	{
-		if (prefs.slist_skip)
+		if (prefs.slist_skip || arg_url)
 			new_ircwindow (NULL, NULL, SESS_SERVER, 0);
 	}
 }
@@ -1038,13 +996,17 @@ xchat_exec (char *cmd)
 int
 main (int argc, char *argv[])
 {
+	int ret;
+	
+	srand (time (0));	/* CL: do this only once! */
 
 #ifdef SOCKS
 	SOCKSinit (argv[0]);
 #endif
 
-	if (!fe_args (argc, argv))
-		return 0;
+	ret = fe_args (argc, argv);
+	if (ret != -1)
+		return ret;
 
 	load_config ();
 
