@@ -174,6 +174,7 @@ struct xchatprefs
 	int completion_sort;
 	int gui_win_state;
 	int gui_usermenu;
+	int gui_join_dialog;
 	int dialog_left;
 	int dialog_top;
 	int dialog_width;
@@ -403,7 +404,7 @@ typedef struct server
 	char servername[128];			/* what the server says is its name */
 	char password[86];
 	char nick[NICKLEN];
-	char linebuf[522];				/* RFC says 512 including \r\n */
+	char linebuf[2048];				/* RFC says 512 chars including \r\n */
 	char *last_away_reason;
 	int pos;								/* current position in linebuf */
 	int nickcount;
@@ -497,4 +498,7 @@ struct popup
 	char *name;
 };
 
+/* CL: get a random int in the range [0..n-1]. DON'T use rand() % n, it gives terrible results. */
+#define RAND_INT(n) ((int)(rand() / (RAND_MAX + 1.0) * (n)))
+
 #endif
