@@ -1,7 +1,7 @@
 /*
  * about.h - utilities for displaying and hiding the about dialog
  *
- * Copyright (C) 2004-2005 xchat-gnome team
+ * Copyright (C) 2004-2006 xchat-gnome team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,7 +24,6 @@
 #ifndef XCHAT_GNOME_ABOUT_H
 #define XCHAT_GNOME_ABOUT_H
 
-void initialize_about_dialog ();
-void show_about_dialog ();
+void show_about_dialog (void);
 
 #endif
