@@ -19,26 +19,28 @@
  *
  */
 
+#ifndef XCHAT_GNOME_GUI_H
+#define XCHAT_GNOME_GUI_H
+
 #include <glade/glade.h>
 #include <gtk/gtkactiongroup.h>
 #include <gtk/gtkuimanager.h>
+#include <gnome.h>
 #include "userlist.h"
 #include "navigation-tree.h"
 #include "dcc-window.h"
+#include "preferences-dialog.h"
 #include "xtext.h"
 
 #include "../common/xchat.h"
 
-#ifndef XCHAT_GNOME_GUI_H
-#define XCHAT_GNOME_GUI_H
-
 typedef struct
 {
 	GladeXML *xml;
 	GladeXML *setup_xml;
 	GtkActionGroup *action_group;
 	GtkUIManager *manager;
-	GtkWidget *about;
+	PreferencesDialog *prefs_dialog;
 	DccWindow *dcc;
 	GtkExpander *topic_expander;
 	GtkWidget *userlist_window;
@@ -56,6 +58,8 @@ typedef struct
 
 	NavModel *tree_model;
 	NavTree *server_tree;
+
+	GnomeProgram *program;
 } XChatGUI;
 
 extern XChatGUI gui;
