@@ -1,7 +1,7 @@
 /*
  * irc-network.h - an object which interfaces around the core 'ircnet'
  *
- * Copyright (C) 2004-2005 xchat-gnome team
+ * Copyright (C) 2004-2006 xchat-gnome team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -44,10 +44,12 @@ struct _IrcNetwork
 	gchar *name;
 	gboolean autoconnect;
 	gboolean use_ssl;
+	gboolean allow_invalid;
 	gboolean cycle;
 	gboolean reconnect;
 	gboolean nogiveup_reconnect;
 
+	gchar *nickserv_password;
 	gchar *password;
 	gint encoding;
 
