@@ -69,7 +69,6 @@ static void      on_server_channel_list (GtkAction *action, gpointer data);
 static void      on_save (GtkAction *action, gpointer data);
 static void      on_close (GtkAction *action, gpointer data);
 static void      on_find (GtkAction *action, gpointer data);
-static void      on_clear (GtkAction *action, gpointer data);
 static void      on_channel_leave (GtkAction *action, gpointer data);
 static void      on_channel_bans (GtkAction *action, gpointer data);
 static void      on_server_autoconnect (GtkAction *action, gpointer data);
@@ -88,22 +87,20 @@ static GtkActionEntry action_entries[] = {
 	{"ChannelLeave",      GTK_STOCK_QUIT,           N_("_Leave"),           "", NULL, G_CALLBACK (on_channel_leave)},
 	{"ChannelClose",      GTK_STOCK_CLOSE,          N_("_Close"),           "", NULL, G_CALLBACK (on_close)},
 	{"ChannelFind",       GTK_STOCK_FIND,           N_("_Find..."),         "", NULL, G_CALLBACK (on_find)},
-	{"ChannelClear",      GTK_STOCK_CLEAR,          N_("C_lear"),           "", NULL, G_CALLBACK (on_clear)},
 	{"ChannelBans",       GTK_STOCK_DIALOG_WARNING, N_("_Bans..."),         "", NULL, G_CALLBACK (on_channel_bans)},
 
 	/* Dialog context menu */
 	{"DialogSave",        GTK_STOCK_SAVE,           N_("_Save Transcript"), "", NULL, G_CALLBACK (on_save)},
 	{"DialogClose",       GTK_STOCK_CLOSE,          N_("_Close"),           "", NULL, G_CALLBACK (on_close)},
 	{"DialogFind",        GTK_STOCK_FIND,           N_("_Find..."),         "", NULL, G_CALLBACK (on_find)},
-	{"DialogClear",       GTK_STOCK_CLEAR,          N_("C_lear"),           "", NULL, G_CALLBACK (on_clear)},
 };
 
 static GtkToggleActionEntry toggle_action_entries[] = {
 	/* Server context menu */
-	{"ServerAutoConnect", NULL, N_("_Auto-connect"), "", NULL, G_CALLBACK (on_server_autoconnect), FALSE},
+	{"ServerAutoConnect", NULL, N_("_Auto-connect on startup"), "", NULL, G_CALLBACK (on_server_autoconnect), FALSE},
 
 	/* Channel context menu */
-	{"ChannelAutoJoin",   NULL, N_("_Auto-join"),    "", NULL, G_CALLBACK (on_channel_autojoin), FALSE},
+	{"ChannelAutoJoin",   NULL, N_("_Auto-join on startup"),    "", NULL, G_CALLBACK (on_channel_autojoin), FALSE},
 };
 
 static GtkActionGroup *action_group;
@@ -255,40 +252,44 @@ navigation_tree_create_new_network_entry (NavTree *navtree, struct session *sess
 }
 
 void
-navigation_tree_create_new_channel_entry (NavTree *navtree, struct session *sess)
+navigation_tree_create_new_channel_entry (NavTree *navtree, struct session *sess, gboolean focus)
 {
 	GtkWidget *menuitem, *button;
-	GtkTreeView *treeview;
 	ircnet *net;
 
 	navigation_model_add_new_channel (navtree->model, sess);
 
-	navigation_tree_select_session (navtree, sess);
+	if (focus) {
+		navigation_tree_select_session (navtree, sess);
 
-	/* We rely on the above select_session call triggering the selection 'changed' event to do book-keeping */
+		/* We rely on the above select_session call triggering the selection 'changed' event to do book-keeping */
 
-	/* Update the row refs here. */
-	navigation_tree_update_refs (navtree);
+		/* Update the row refs here. */
+		navigation_tree_update_refs (navtree);
 
-	/* Set the userlist model */
-	treeview = GTK_TREE_VIEW (glade_xml_get_widget (gui.xml, "userlist"));
-	gtk_tree_view_set_model (treeview, GTK_TREE_MODEL (userlist_get_store (u, sess)));
+		/* Set the userlist model */
+		gtk_tree_view_set_model (GTK_TREE_VIEW (gui.userlist),
+		                         GTK_TREE_MODEL (userlist_get_store (u, sess)));
 
-	topic_label_set_current (TOPIC_LABEL (gui.topic_label), sess);
-	net = sess->server->network;
-	if (net == NULL)
-		rename_main_window (NULL, sess->channel);
-	else
-		rename_main_window (net->name, sess->channel);
+		topic_label_set_current (TOPIC_LABEL (gui.topic_label), sess);
+		net = sess->server->network;
+		if (net == NULL)
+			rename_main_window (NULL, sess->channel);
+		else
+			rename_main_window (net->name, sess->channel);
 
-	button = glade_xml_get_widget (gui.xml, "close discussion");
-	if (sess->type == SESS_CHANNEL)
-		gtk_widget_set_sensitive (button, TRUE);
-	menuitem = gtk_ui_manager_get_widget (gui.manager, "/ui/menubar/DiscussionMenu/DiscussionChangeTopicItem");
-	if (menuitem == NULL)
-		g_warning ("can't access topic change menu item");
-	else
-		gtk_widget_set_sensitive (menuitem, sess->type == SESS_CHANNEL);
+		button = glade_xml_get_widget (gui.xml, "close discussion");
+		if (sess->type == SESS_CHANNEL)
+			gtk_widget_set_sensitive (button, TRUE);
+		menuitem = gtk_ui_manager_get_widget (gui.manager, "/ui/menubar/DiscussionMenu/DiscussionChangeTopicItem");
+		if (menuitem == NULL)
+			g_warning ("can't access topic change menu item");
+		else
+			gtk_widget_set_sensitive (menuitem, sess->type == SESS_CHANNEL);
+
+		/* Set our nick. */
+		set_nickname (sess->server, NULL);
+	}
 }
 
 void
@@ -1019,8 +1020,11 @@ click (GtkWidget *treeview, GdkEventButton *event, gpointer data)
 static gboolean
 declick (GtkWidget *treeview, GdkEventButton *e, gpointer data)
 {
+	gint position;
+
+	position = gtk_editable_get_position (GTK_EDITABLE (gui.text_entry));
 	gtk_widget_grab_focus (gui.text_entry);
-	gtk_editable_set_position (GTK_EDITABLE (gui.text_entry), -1);
+	gtk_editable_set_position (GTK_EDITABLE (gui.text_entry), position);
 	g_object_set (G_OBJECT (treeview), "can-focus", TRUE, NULL);
 	return FALSE;
 }
@@ -1028,17 +1032,17 @@ declick (GtkWidget *treeview, GdkEventButton *e, gpointer data)
 static void
 navigation_selection_changed (GtkTreeSelection *treeselection, gpointer user_data)
 {
-	GtkTreeIter iter, newiter;
-	GtkTreeModel *model, *store;
-	GtkTreeView *treeview;
-	GtkWidget *button;
-	gpointer *s;
-	session *sess;
+	GtkTreeIter   iter;
+	GtkTreeIter   newiter;
+	GtkTreeModel *model;
+	GtkTreeModel *store;
+	GtkWidget    *button;
+	gpointer     *s;
+	session      *sess;
 
 	if (gui.server_tree == NULL)
 		return;
 
-	treeview = GTK_TREE_VIEW (glade_xml_get_widget (gui.xml, "userlist"));
 
 	if (gui.server_tree->current_rowref != NULL)
 		navigation_model_rowref_deref (gui.server_tree->current_rowref);
@@ -1077,7 +1081,8 @@ navigation_selection_changed (GtkTreeSelection *treeselection, gpointer user_dat
 		gui.current_session = sess;
 
 		/* Change the model in the userlist to the one for this session. */
-		gtk_tree_view_set_model (treeview, GTK_TREE_MODEL (userlist_get_store (u, sess)));
+		gtk_tree_view_set_model (GTK_TREE_VIEW (gui.userlist),
+				         GTK_TREE_MODEL (userlist_get_store (u, sess)));
 
 		/* Set our nick. */
 		set_nickname (sess->server, NULL);
@@ -1118,6 +1123,7 @@ navigation_selection_changed (GtkTreeSelection *treeselection, gpointer user_dat
 		status_bar_set_current         (STATUS_BAR         (gui.status_bar),         sess->server);
 
 		gtk_widget_grab_focus (gui.text_entry);
+		gtk_editable_set_position (GTK_EDITABLE (gui.text_entry), -1);
 
 		/* Set the label of the user list button */
 		userlist_set_user_button (u, sess);
@@ -1132,6 +1138,8 @@ row_expanded (GtkTreeView *treeview, GtkTreeIter *iter, GtkTreePath *path, gpoin
 {
 	GtkTreePath *current_path;
 
+	if (NAVTREE (treeview)->current_rowref == NULL)
+		return;
 	current_path = gtk_tree_row_reference_get_path (NAVTREE (treeview)->current_rowref);
 
 	/* If we had something selected before the row was collapsed make sure it gets selected. */
@@ -1270,15 +1278,14 @@ static gboolean
 navigation_model_create_new_channel_entry_iterate (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, struct session *data)
 {
 	struct session *s;
+	gint            position;
+
 	gtk_tree_model_get (model, iter, 2, &s, -1);
 	if (s->type == SESS_SERVER && s->server == data->server) {
 		GtkTreeIter child;
-		GtkTreeModelSort *sort;
 		GtkTreeRowReference *rowref;
 		GtkTreePath *path;
 
-		sort = GTK_TREE_MODEL_SORT (gui.tree_model->sorted);
-
 		gtk_tree_store_append (GTK_TREE_STORE (model), &child, iter);
 		/* Add the new channel to the store. By default connected is true. */
 		gtk_tree_store_set (GTK_TREE_STORE (model), &child, 1, data->channel, 2, data, 3, 0, 4, NULL, 5, 0, 6, TRUE, -1);
@@ -1287,10 +1294,9 @@ navigation_model_create_new_channel_entry_iterate (GtkTreeModel *model, GtkTreeP
 		rowref = gtk_tree_row_reference_new (model, path);
 		g_hash_table_insert (gui.tree_model->session_rows, (gpointer) data, (gpointer) rowref);
 
-		/* Set our nick. */
-		set_nickname (s->server, NULL);
-
+		position = gtk_editable_get_position (GTK_EDITABLE (gui.text_entry));
 		gtk_widget_grab_focus (gui.text_entry);
+		gtk_editable_set_position (GTK_EDITABLE (gui.text_entry), position);
 
 		gtk_tree_path_free (path);
 		return TRUE;
@@ -1527,12 +1533,13 @@ on_server_reconnect (GtkAction * action, gpointer data)
 static void
 on_server_disconnect (GtkAction * action, gpointer data)
 {
-	GtkTreeView *treeview;
+	GtkTreeView      *treeview;
 	GtkTreeSelection *select;
-	GtkTreeModel *model, *store;
-	GtkTreeIter iter, newiter;
-	session *s;
-	gboolean temp;
+	GtkTreeModel     *model;
+	GtkTreeModel     *store;
+	GtkTreeIter       iter;
+	GtkTreeIter       newiter;
+	session          *s;
 
 	treeview = GTK_TREE_VIEW (gui.server_tree);
 	select = gtk_tree_view_get_selection (treeview);
@@ -1586,21 +1593,6 @@ on_close (GtkAction * action, gpointer data)
 	if (gtk_tree_selection_get_selected (select, &model, &iter)) {
 		gtk_tree_model_get (model, &iter, 2, &s, 6, &joined, -1);
 
-		if (s->type == SESS_CHANNEL && joined) {
-			GConfClient *client;
-			gchar *text;
-
-			client = gconf_client_get_default ();
-			text = gconf_client_get_string (client, "/apps/xchat/irc/partmsg", NULL);
-			if (text == NULL)
-				text = g_strdup (_("Ex-Chat"));
-			s->server->p_part (s->server, s->channel, text);
-			g_object_unref (client);
-			g_free (text);
-		} else if (s->type == SESS_SERVER && joined) {
-			s->server->disconnect (s, TRUE, -1);
-		}
-
 		if (s->type == SESS_SERVER)
 			status_bar_remove_server (STATUS_BAR (gui.status_bar), s->server);
 		conversation_panel_remove_session (CONVERSATION_PANEL (gui.conversation_panel), s);
@@ -1616,16 +1608,6 @@ on_find (GtkAction * action, gpointer data)
 	find_bar_open (FIND_BAR (gui.find_bar));
 }
 
-static void
-on_clear (GtkAction * action, gpointer data)
-{
-	session *s;
-
-	s = navigation_tree_get_selected_session (NULL);
-	if (s)
-		conversation_panel_clear (CONVERSATION_PANEL (gui.conversation_panel), s);
-}
-
 static void
 on_channel_leave (GtkAction * action, gpointer data)
 {
@@ -1640,7 +1622,7 @@ on_channel_leave (GtkAction * action, gpointer data)
 	if (gtk_tree_selection_get_selected (select, &model, &iter)) {
 		gtk_tree_model_get (model, &iter, 2, &s, -1);
 		store = gtk_tree_model_sort_get_model (GTK_TREE_MODEL_SORT (model));
-		if (s->type == SESS_CHANNEL) {
+		if ((s->type == SESS_CHANNEL) && (s->channel[0] != '\0')) {
 			GConfClient *client;
 			gchar *text;
 
